<template>
  <Popup ref="pop" :title="form.title" left="calc(100% - 330px)" width="360px">
    <div class="terrainOutline">
      <el-form ref="form" :model="form" label-width="120px">
        <el-form-item label="采样间隔(米)">
          <el-input-number
            v-model="form.input"
            controls-position="right"
            @change="handleChange"
            :min="1"
            :max="100"
          ></el-input-number>
          <el-button type="primary" @click="startAnalysis">开始分析</el-button>
        </el-form-item>
      </el-form>
    </div>
  </Popup>
</template>
<script>
import Popup from "@tools/Popup.vue";
let distance = 50;
export default {
  name: "terrainOutline",
  components: {
    Popup,
  },
  data() {
    return {
      form: {
        title: "地形轮廓",
        input: 50,
      },
    };
  },
  computed: {},
  mounted() {},
  methods: {
    // 关闭弹窗
    close() {
      this.$refs.pop.close();
    },
    // 打开弹窗
    open() {
      this.$refs.pop.open();
    },
    // 输入框数据修改
    handleChange() {
      distance = this.form.input;
    },
    clear() {
      layer.close(this.layerIndex);
      this.layerIndex = undefined;
      if (window.AnalysisDXPM) {
        window.AnalysisDXPM.flyPoint &&
          Viewer.entities.remove(window.AnalysisDXPM.flyPoint);
        window.AnalysisDXPM && window.AnalysisDXPM.deleteObject();
        window.AnalysisDXPM = undefined;
      }
    },
    // 开始绘制
    startAnalysis() {
      this.clear();

      window.AnalysisDXPM = sgworld.Command.execute(
        2,
        6,
        { cyjj: distance, objid: 0 },
        (Distance) => {
          if (Distance.gcs && Distance.gcs.length) {
            window.AnalysisDXPM.analyseData = Distance;
            this.layerIndex = layer.open({
              type: 2,
              title: "分析结果",
              shade: false,
              area: ["80%", "280px"],
              offset: "b",
              skin: "other-class",
              content:
                window.SmartEarthRootUrl + "Workers/analysis/AnalysisDXPM.html",
              end: () => {
                this.layerIndex && this.clear();
              },
            });
          } else {
            //剖面
            window.AnalysisDXPM && window.AnalysisDXPM.deleteObject();
          }
        }
      );
    },
  },
};
</script>
<style lang="less">
.terrainOutline {
  .el-input-number {
    width: 100px !important;
  }
  .el-button {
    margin-left: 10px;
  }
}
</style>